<?php

namespace Drupal\google_webfonts_helper\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides settings form for module.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The file system.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * Constructs a new SettingsForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\File\FileSystemInterface $file_system
   *   The file system.
   */
  public function __construct(ConfigFactoryInterface $config_factory, FileSystemInterface $file_system) {
    parent::__construct($config_factory);
    $this->fileSystem = $file_system;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('file_system')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'google_webfonts_helper_settings';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $form['fonts_path'] = [
      '#type' => 'textfield',
      '#title' => new TranslatableMarkup('Fonts path'),
      '#description' => new TranslatableMarkup('Path to store fonts. The path must be accessible from internet.'),
      '#required' => TRUE,
      '#default_value' => $this->config('google_webfonts_helper.settings')
        ->get('fonts_path'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $fonts_path = $form_state->getValue('fonts_path');
    $fonts_path_scheme = $this->fileSystem->uriScheme($fonts_path);
    if (!$this->fileSystem->validScheme($fonts_path_scheme)) {
      $form_state->setErrorByName('fonts_path', new TranslatableMarkup('You enter invalid scheme.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('google_webfonts_helper.settings')
      ->set('fonts_path', $form_state->getValue('fonts_path'))
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'google_webfonts_helper.settings',
    ];
  }

}
